--[[
	Glyph Reporter
	
	Coded by Earl_Parvisjam

	This addon reports known and needed glyphs for all characters on the current server.
	
   ]]
   
GlyphReporter_Version = "1.2";
ReporterDB = {};
GR_Color = { ["name"] = "Red", ["r"] = 1, ["g"] = 0, ["b"] = 0 };
local realm = GetRealmName();
local player = UnitName("player");

---------------------------------------------------
-- OnLoad
---------------------------------------------------

function GlyphReporter_OnLoad(self)
	self:RegisterEvent("GLYPH_ENABLED");
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
	GlyphReporter_Print("Glyph Reporter v" ..GlyphReporter_Version .. " has been loaded successfully.");
end

---------------------------------------------------
-- OnEvent
---------------------------------------------------

function GlyphReporter_OnEvent(self, event)
	if (event == "PLAYER_ENTERING_WORLD") then
		if (ReporterDB[realm] == nil) then
			ReporterDB[realm] = {};
			ReporterDB[realm][player] = {};	
			GR_ColorSelectButton_OnLoad(GR_ColorSelectButton);	
		end
	end
	GlyphReporter_GrabCurrentData();
end



---------------------------------------------------
-- GrabCurrentData
-- Summary:  Grabs all current Glyph info
---------------------------------------------------
function GlyphReporter_GrabCurrentData()
	local glyphList = {};
	if (GetNumGlyphs() > 0) then
		for index = 1, GetNumGlyphs() do
			local name, glyphType, isKnown = GetGlyphInfo(index);
			if (name ~= "header") then
				glyphList[name] = { ["Type"] = glyphType, ["Known"] = isKnown };
			end			
		end
	end
	local Player = { ["Glyphs"] = glyphList };
	ReporterDB[realm][player] = Player;
end

---------------------------------------------------
-- CheckNeed
-- Summary:  Grabs all needy characters
---------------------------------------------------
function GlyphReporter_CheckNeed(glyphName)
	local removeThe = string.sub(glyphName, 5);
	local needList = "Needed by:  ";
	GlyphReporter_GrabCurrentData();
	for currentPlayer, value in pairs(ReporterDB[GetRealmName()]) do
		if ((value["Glyphs"][glyphName] ~= nil) and (value["Glyphs"][glyphName]["Known"] == false)) then
				needList = needList ..currentPlayer;
		elseif ((value["Glyphs"][removeThe] ~= nil) and (value["Glyphs"][removeThe]["Known"] == false)) then
				needList = needList ..currentPlayer;
		end
	end
	return needList;
end

function GlyphReporter_Print(msg)
	if (msg == nil) then return; end
	if( DEFAULT_CHAT_FRAME ) then DEFAULT_CHAT_FRAME:AddMessage(msg, 1,1, 0); end
end

local setOnce = {};
---------------------------------------------------
-- ToolTipHooker
-- Summary:  Hooks extra text onto the tooltip
---------------------------------------------------
local function ToolTipHooker(self, ...)
	if (not setOnce[self]) then
		local itemLink = select(2, self:GetItem());
		if itemLink and GetItemInfo(itemLink) then
			local itemName, _, _, _, _, itemType = GetItemInfo(itemLink);
			if ("Glyph" == itemType) then
				local list = GlyphReporter_CheckNeed(string.sub(itemName, 10));
				self:AddLine(list, GR_Color.r, GR_Color.g, GR_Color.b);
				setOnce[self] = true;
			end

		end
	end
end

---------------------------------------------------
-- ToolTipUnHooker
-- Summary:  Unhooks extra text on the tooltip
---------------------------------------------------
local function ToolTipUnhooker(self, ...)
	setOnce[self] = false;
end

GameTooltip:HookScript("OnTooltipSetItem", ToolTipHooker);
GameTooltip:HookScript("OnTooltipCleared", ToolTipUnhooker);

---------------------------------------------------
-- ***Interface Options Framework***
---------------------------------------------------

local colorList = { 
	["White"] = { ["r"] = 1, ["g"] = 1, ["b"] = 1,},
	["Yellow"] = { ["r"] = 1, ["g"] = 1, ["b"] = 0,},
	["Red"] = { ["r"] = 1, ["g"] = 0, ["b"] = 0,},
	["Green"] = { ["r"] = 0, ["g"] = 1, ["b"] = 0,},
	["Blue"] = { ["r"] = 0, ["g"] = 0, ["b"] = 1,},
	
}

---------------------------------------------------
-- GR_GUIFrame_OnLoad
---------------------------------------------------
function GR_GUIFrame_OnLoad(panel)
	panel.name = "Glyph Reporter";
	panel.okay = function (self) GR_ColorSelectButton_OnClick(); end;
	panel.cancel = function (self) GR_ColorSelectButton_Close(); end
	InterfaceOptions_AddCategory(panel);
end

---------------------------------------------------
-- GR_ColorSelect_OnLoad
---------------------------------------------------
function GR_ColorSelectButton_OnLoad(self)
	local info = UIDropDownMenu_CreateInfo();
	self.text = "Invalid";
	for k,v in pairs(colorList) do
		info.text = k;
		info.checked = false;
		if (k == GR_Color["name"]) then
			self.text = k;
			info.checked = true;
		end
		--info.r = v.r;
		--info.g = v.g;
		--info.b = v.b;
		--info.hasColorSwatch = true;
		info.func = function (self) GR_ColorClick(self); end;
		UIDropDownMenu_AddButton(info);
	UIDropDownMenu_SetText(self, self.text);
	end
	self.text = UIDropDownMenu_GetSelectedName("GR_ColorSelectButton");
end

---------------------------------------------------
-- GR_ColorSelect_OnClick
---------------------------------------------------

local function GR_ColorSelectButton_OnClick(self)
	--UIDropDownMenu_SetText(self, self.value);
	ToggleDropDownMenu(1, nil, GR_ColorSelectButton, "GR_ColorSelectButton", 0, 0);
end

---------------------------------------------------
-- GR_ColorClick
-- Summary:  Action taken when the button is clicked
---------------------------------------------------
function GR_ColorClick(self)
	GR_Color.name = self.value;
	self.checked = true;
	GR_Color.r = colorList[self.value].r;
	GR_Color.g = colorList[self.value].g;
	GR_Color.b = colorList[self.value].b;
	ToggleDropDownMenu(1, nil, GR_ColorSelectButton, "GR_ColorSelectButton", 0, 1);
end

function GR_ColorSelectButton_Close(self)
	UIDropDownMenu_SetText(self, self.value);
end